import click

from albhed import AlBhed


@click.command()
@click.option(
    "-r", "--revert", is_flag=True, default=False, help="Revert the translation"
)
@click.argument("string", nargs=-1)
def cli(revert: bool, string: str) -> None:
    """
    Converts Any Text to Al Bhed
    """
    t = AlBhed(" ".join(string))
    if revert:
        print(t.revert())
    else:
        print(t.translate())


if __name__ == "__main__":
    cli()



class AlBhed:
    def __init__(self, text: str) -> None:
        self.cha_english = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
        self.cha_albhed = "ypltavkrezgmshubxncdijfqowYPLTAVKREZGMSHUBXNCDIJFQOW"
        self.text = text

    def translate(self) -> str:
        return self.text.translate(str.maketrans(self.cha_english, self.cha_albhed))

    def revert(self) -> str:
        return self.text.translate(str.maketrans(self.cha_albhed, self.cha_english))
